import numpy as np              # Library for numerical computations
import matplotlib.pyplot as plt # Library for plotting
from math import factorial      # Using Python's built-in factorial function

# Number of terms for the Maclaurin series expansion
num_terms = 100

# Function definitions
def C_approx (t, terms=num_terms) :
    """Maclaurin series approximation of C(t) """
    result = 0
    for n in range(terms):
        # Compute each term of the series
        term = ((-1)**n / factorial(2*n)) * (t**(4*n+1)) / (4*n+1)
        result += term
    return result
    
def S_approx(t, terms=num_terms):
    "''Maclaurin series approximation of S(t)"""
    result = 0
    for n in range(terms):
        # Compute each term of the series
        term = ((-1)**n / factorial(2*n+1)) * (t**(4*n+3)) / (4*n+3)
        result += term
    return result

# Generate data for plotting
t_values = np.linspace(0, 10, 1000) # Adjustable range of t
C_values = [C_approx(t) for t in t_values]   # Compute C(t) values
S_values = [S_approx(t) for t in t_values]   # Compute S(t) values

# Plot
plt.figure(figsize=(10, 10))
plt.plot(C_values, S_values, label="Clothoid curve, by power series display",
         color="blue")
plt.axhline(0, color="black", linewidth=1.0, linestyle="--")
plt.axvline(0, color="black", linewidth=1.0, linestyle="--")
plt.title("ParametricuPlotuofu$(C(t), S(t))$", fontsize=10)
plt.xlabel("$C(t)$", fontsize=10)
plt.ylabel("$S(t)$", fontsize=10)
plt.legend(fontsize=10)
plt.grid(alpha=0.5)
plt.axis("equal")
plt.savefig('list1.pdf')
plt.show()
