import numpy as np # Library for numerical computations
import matplotlib.pyplot as plt # Library for plotting
import scipy.special as sc

def myfresnel(x):
    factor = np.sqrt(np.pi / 2)
    [s, c] = sc.fresnel(x / factor)
    return [factor * s, factor * c]
            
def plot_clothoid(t_max, num_points):
    """
    Function to plot a Clothoid (Cornu spiral)
    Parameters: t_max: float
    Maximum arc length (maximum value of t)
    num_points: int
    Number of divisions for the arc length (number of points for t)
    """
    # Generate values for the arc length t
    t = np.linspace(0, t_max, num_points)

    # Use myfresnel to get the Clothoid curve
    S, C = zip(*[myfresnel(ti) for ti in t])

    # Plotting
    plt.figure(figsize=(10, 10))
    plt.plot(C, S, label="Clothoid curve by myfresnel", color="blue")
    plt.axhline(0, color="black", linewidth=1.0, linestyle="--")
    plt.axvline(0, color="black", linewidth=1.0, linestyle="--")
    plt.title("Parametric Plot of $(C(t), S(t))$", fontsize=10)
    plt.xlabel("$C(t)$", fontsize=10)
    plt.ylabel("$S(t)$", fontsize=10)
    plt.legend(fontsize=10)
    plt.grid(alpha=0.5)
    plt.axis("equal")
    plt.savefig('list2.pdf')
    plt.show()
    
# Execute the function
plot_clothoid(t_max=100, num_points=10000)
