import numpy as np              # Library for numerical computations
import matplotlib.pyplot as plt # Library for plotting
import scipy.special as sc
import time

# Define the Fresnel function
def myfresnel(x):
    factor = np.sqrt(np.pi / 2)
    s, c = sc.fresnel(x / factor)
    return factor * s, factor * c

# Define the function to plot the clothoid
def plot_clothoid(t_max, num_points):

    # Generate values for the arc length t
    t = np.linspace(0, t_max, num_points)

    # Use myfresnel to get the Clothoid curve
    S, C = zip(*[myfresnel(ti) for ti in t])
    
# Initialize list to store computation times
computation_times = []

# Run the function 100 times and record computation times
for _ in range (1000):
    start_time = time.time()
    plot_clothoid(t_max=100, num_points=10000)
    end_time = time.time()
    computation_times.append(end_time - start_time)

# Compute the average computation time
average_time = np.mean(computation_times)

# Plot the computation times as points
plt.figure(figsize=(10, 5))
plt.plot(computation_times, 'o', label="Computation Time per Run",
         color='blue')
  # Use 'o' for points
plt.axhline(y=average_time, color='red', linestyle='--',
            label=f"Average Time = {average_time:.4f}s")
plt.xlabel('Run_Number')
plt.ylabel('Computation Time (seconds)')
plt.title('Computation Time for 1000 Runs')
plt.legend()
plt.grid(True)
plt.savefig('list3.pdf')
plt.show()

# Print the average computation time
print (f" Average computation time: {average_time:.4f} seconds")
