import numpy as np # Library for numerical computations
import matplotlib.pyplot as plt # Library for plotting
from scipy.integrate import solve_ivp # Function to solve initial value problems for ODEs
import time

# Define the right-hand side of the ode for ct)
def dc_dt(t, c):
    return np.cos(t**2)

# Define the right-hand side of the ODE for s(t)
def ds_dt(t, s):
    return np.sin(t**2)

# Function to solve ODEs and generate the clothoid plot
def solve_and_plot():
    # Initial conditions and time range
    c0 = 0 # Initial condition for c(0)
    s0 = 0 # Initial condition for s(0)
    t_span = (0, 100) # Time range: t E LO, 100]
    t_eval = np.linspace(0, 100, 10000) # Time points for evaluation (for plotting)
    # Solve the ODE for c(t) using solve_ivp
    c_solution = solve_ivp(dc_dt, t_span, [c0], method='RK45', t_eval=t_eval,
                           rtol=1e-6, ato1=1e-8)
    C_values = c_solution.y[0] # Extract the values of c(t)
    # Solve the ODE for s(t) using solve_ivp
    s_solution = solve_ivp(ds_dt, t_span, [s0], method='RK45', t_eval=t_eval,
                           rtol=1e-6, atol=1e-8)
    S_values = s_solution.y[0] # Extract the values of s(t)

    # Plot
    plt.figure(figsize=(10, 10))
    plt.plot(C_values, S_values,
             label="Clothoid curve by separate ODE solutions", color ="blue")
    plt.axhline(0, color="black", linewidth=1.0, linestyle="--")
    plt.axvline(0, color="black", linewidth=1.0, linestyle="--")
    plt.title("Parametric Plot of $(C(t), S(t))$", fontsize=10)
    plt.xlabel("$C(t)$", fontsize=10)
    plt.ylabel("$S(t)$", fontsize=10)
    plt.legend(fontsize=10)
    plt.grid(alpha=0.5)
    plt.axis("equal")
    plt.show()

# Call the function to execute the computation and plot
solve_and_plot()
