import numpy as np # Library for numerical computations
import matplotlib.pyplot as plt # Library for plotting
from scipy.special import erf # Error function for Fresnel integrals
import time

# Define constants
sqrt_pi = np.sqrt(np.pi)  # Square root of pi
sqrt_i = np.sqrt(1j)      # Square root of imaginary unit i
sqrt_neg_i = np.sqrt(-1j) # Square root of -i

# Compute Fresnel integral C(z)
def fresnel_C(z):
    return (sqrt_pi/4)*(sqrt_neg_i*erf(sqrt_i*z) + sqrt_i*erf(sqrt_neg_i*z))

# Compute Fresnel integral S(z)
def fresnel_S (z):
    return (sqrt_pi/4)*(sqrt_i*erf(sqrt_i*z) + sqrt_neg_i*erf(sqrt_neg_i*z))

# Generate the clothoid curve
def generate_clothoid(t_vals):
    C_vals = fresnel_C(t_vals)
    S_vals = fresnel_S(t_vals)
    return C_vals.real, S_vals.real

# Define the range of parameter t
t_vals = np.linspace(0, 100, 10000)

# Initialize list to store computation times
computation_times = []

# Run the function 1000 times and record computation times
for _ in range(1000):
    start_time = time.time()
    generate_clothoid(t_vals)
    end_time = time.time()

    computation_times.append(end_time - start_time)

# Compute the average computation time
average_time = np.mean(computation_times)

# Plot the computation times as points
plt.figure(figsize=(10, 5))
plt.plot(computation_times, 'o', label="Computation Time per Run", color='blue')
# Use 'o' for points
plt.axhline(y=average_time, color='red', linestyle='--',
            label=f"Average Time = {average_time:.4f}s")
plt.xlabel('Run Number')
plt.ylabel('Computation Timeu(seconds)')
plt.title('Computation Time for 1000-Runs')
plt.legend()
plt.grid(True)
plt.show()
# Print the average computation time
print(f"Average computation time: {average_time:.4f} seconds")

